@@ -1,5 +1,5 @@
 // rak - Rakshasa's toolbox
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -29,10 +29,8 @@
 // If you delete this exception statement from all source files in the
 // program, then also delete it here.
 //
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
+// Contact:  Jari Sundell <sundell.software@gmail.com>
+
 
 #ifndef RAK_UNORDERED_VECTOR_H
 #define RAK_UNORDERED_VECTOR_H
@@ -75,8 +73,12 @@ public:
   using Base::push_back;
   using Base::pop_back;
 
+  // Use the range erase function, the single element erase gets
+  // overloaded.
+  using Base::erase;
+
   iterator            insert(iterator position, const value_type& x);
-  iterator            erase(iterator position);  
+  iterator            erase(iterator position);
 
 private:
 };
