@@ -1,48 +1,11 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef RTORRENT_CONTROL_H
 #define RTORRENT_CONTROL_H
 
 #include <atomic>
 #include <cinttypes>
 #include <sys/types.h>
-#include <rak/timer.h>
-#include <rak/priority_queue_default.h>
 #include <torrent/torrent.h>
+#include <torrent/utils/scheduler.h>
 
 namespace ui {
   class Root;
@@ -61,12 +24,13 @@ namespace display {
 namespace input {
   class InputEvent;
   class Manager;
-}  
+}
 
 namespace rpc {
   class CommandScheduler;
   class XmlRpc;
   class object_storage;
+  class LuaEngine;
 }
 
 namespace torrent {
@@ -77,7 +41,7 @@ class Control {
 public:
   Control();
   ~Control();
-  
+
   bool                is_shutdown_completed();
   bool                is_shutdown_received()        { return m_shutdownReceived; }
   bool                is_shutdown_started()         { return m_shutdownQuick; }
@@ -102,6 +66,7 @@ public:
 
   rpc::CommandScheduler* command_scheduler()        { return m_commandScheduler; }
   rpc::object_storage*   object_storage()           { return m_objectStorage; }
+  rpc::LuaEngine*        lua_engine()               { return m_lua_engine; }
 
   torrent::directory_events* directory_events()     { return m_directory_events; }
 
@@ -126,17 +91,18 @@ private:
 
   rpc::CommandScheduler*     m_commandScheduler;
   rpc::object_storage*       m_objectStorage;
+  rpc::LuaEngine*            m_lua_engine;
   torrent::directory_events* m_directory_events;
 
-  uint64_t            m_tick;
+  uint64_t            m_tick{};
 
   mode_t              m_umask;
   std::string         m_workingDirectory;
 
-  rak::priority_item  m_taskShutdown;
+  torrent::utils::SchedulerEntry m_task_shutdown;
 
-  std::atomic<bool>   m_shutdownReceived;
-  std::atomic<bool>   m_shutdownQuick;
+  std::atomic<bool>   m_shutdownReceived{};
+  std::atomic<bool>   m_shutdownQuick{};
 };
 
 #endif
