@@ -1,50 +1,12 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <list>
 #include <rak/file_stat.h>
-#include <rak/functional.h>
 #include <rak/path.h>
 #include <torrent/exceptions.h>
 #include <torrent/rate.h>
 #include <torrent/torrent.h>
-#include <torrent/tracker.h>
-#include <torrent/tracker_list.h>
+#include <torrent/tracker/tracker.h>
 #include <torrent/data/file_list.h>
 
 #include "rpc/parse_commands.h"
@@ -56,11 +18,7 @@
 namespace core {
 
 Download::Download(download_type d) :
-  m_download(d),
-  m_hashFailed(false),
-
-  m_resumeFlags(~uint32_t()),
-  m_group(0) {
+    m_download(d) {
 
   m_download.info()->signal_tracker_success().push_back(std::bind(&Download::receive_tracker_msg, this, ""));
   m_download.info()->signal_tracker_failed().push_back(std::bind(&Download::receive_tracker_msg, this, std::placeholders::_1));
@@ -75,13 +33,17 @@ Download::~Download() {
 
 void
 Download::enable_udp_trackers(bool state) {
-  for (torrent::TrackerList::iterator itr = m_download.tracker_list()->begin(), last = m_download.tracker_list()->end(); itr != last; ++itr)
-    if ((*itr)->type() == torrent::Tracker::TRACKER_UDP) {
-      if (state)
-        (*itr)->enable();
-      else
-        (*itr)->disable();
-    }
+  for (int idx = 0, end = m_download.tracker_controller().size(); idx < end; ++idx) {
+    auto tracker = m_download.tracker_controller().at(idx);
+
+    if (tracker.type() != torrent::TRACKER_UDP)
+      continue;
+
+    if (state)
+      tracker.enable();
+    else
+      tracker.disable();
+  }
 }
 
 uint32_t
