@@ -37,21 +37,20 @@ is_network_uri(const std::string& uri) {
     std::strncmp(uri.c_str(), "ftp://", 6) == 0;
 }
 
-static bool
-download_factory_add_stream(torrent::Object* root, const char* key, const char* filename) {
+static std::unique_ptr<torrent::Object>
+download_factory_load_stream(const char* filename) {
   std::fstream stream(filename, std::ios::in | std::ios::binary);
 
   if (!stream.is_open())
-    return false;
+    return std::unique_ptr<torrent::Object>();
 
-  torrent::Object obj;
-  stream >> obj;
+  auto obj = std::make_unique<torrent::Object>();
+  stream >> *obj;
 
   if (!stream.good())
-    return false;
+    return std::unique_ptr<torrent::Object>();
 
-  root->insert_key_move(key, obj);
-  return true;
+  return obj;
 }
 
 bool
@@ -61,20 +60,10 @@ is_magnet_uri(const std::string& uri) {
 }
 
 DownloadFactory::DownloadFactory(Manager* m) :
-  m_manager(m),
-  m_stream(NULL),
-  m_object(NULL),
-  m_commited(false),
-  m_loaded(false),
+    m_manager(m) {
 
-  m_session(false),
-  m_start(false),
-  m_printLog(true),
-  m_isFile(false),
-  m_initLoad(false) {
-
-  m_taskLoad.slot() = std::bind(&DownloadFactory::receive_load, this);
-  m_taskCommit.slot() = std::bind(&DownloadFactory::receive_commit, this);
+  m_task_load.slot() = std::bind(&DownloadFactory::receive_load, this);
+  m_task_commit.slot() = std::bind(&DownloadFactory::receive_commit, this);
 
   // m_variables["connection_leech"] = rpc::call_command("protocol.connection.leech");
   // m_variables["connection_seed"]  = rpc::call_command("protocol.connection.seed");
@@ -85,8 +74,8 @@ DownloadFactory::DownloadFactory(Manager* m) :
 }
 
 DownloadFactory::~DownloadFactory() {
-  priority_queue_erase(&taskScheduler, &m_taskLoad);
-  priority_queue_erase(&taskScheduler, &m_taskCommit);
+  torrent::this_thread::scheduler()->erase(&m_task_load);
+  torrent::this_thread::scheduler()->erase(&m_task_commit);
 
   delete m_stream;
   delete m_object;
@@ -96,7 +85,7 @@ DownloadFactory::~DownloadFactory() {
 void
 DownloadFactory::load(const std::string& uri) {
   m_uri = uri;
-  priority_queue_insert(&taskScheduler, &m_taskLoad, cachedTime);
+  torrent::this_thread::scheduler()->wait_for(&m_task_load, 0ms);
 }
 
 // This function must be called before DownloadFactory::commit().
@@ -111,7 +100,7 @@ DownloadFactory::load_raw_data(const std::string& input) {
 
 void
 DownloadFactory::commit() {
-  priority_queue_insert(&taskScheduler, &m_taskCommit, cachedTime);
+  torrent::this_thread::scheduler()->wait_for(&m_task_commit, 0ms);
 }
 
 void
@@ -173,9 +162,19 @@ DownloadFactory::receive_commit() {
 
 void
 DownloadFactory::receive_success() {
+  auto rtorrent_object = download_factory_load_stream((rak::path_expand(m_uri) + ".rtorrent").c_str());
+  auto libtorrent_resume_object = download_factory_load_stream((rak::path_expand(m_uri) + ".libtorrent_resume").c_str());
+
+  uint32_t tracker_key;
+
+  if (rtorrent_object && rtorrent_object->has_key_value("key"))
+    tracker_key = rtorrent_object->get_key_value("key");
+  else
+    tracker_key = random() % (std::numeric_limits<uint32_t>::max() - 1) + 1;
+
   Download* download = m_stream != NULL ?
-    m_manager->download_list()->create(m_stream, m_printLog) :
-    m_manager->download_list()->create(m_object, m_printLog);
+    m_manager->download_list()->create(m_stream, tracker_key, m_printLog) :
+    m_manager->download_list()->create(m_object, tracker_key, m_printLog);
 
   m_object = NULL;
 
@@ -200,8 +199,11 @@ DownloadFactory::receive_success() {
   }
 
   if (m_session) {
-    download_factory_add_stream(root, "rtorrent", (rak::path_expand(m_uri) + ".rtorrent").c_str());
-    download_factory_add_stream(root, "libtorrent_resume", (rak::path_expand(m_uri) + ".libtorrent_resume").c_str());
+    if (rtorrent_object)
+      root->insert_key_move("rtorrent", *rtorrent_object);
+
+    if (libtorrent_resume_object)
+      root->insert_key_move("libtorrent_resume", *libtorrent_resume_object);
 
   } else {
     // We only allow session torrents to keep their
@@ -213,6 +215,8 @@ DownloadFactory::receive_success() {
   torrent::Object* rtorrent = &root->insert_preserve_copy("rtorrent", torrent::Object::create_map()).first->second;
   torrent::Object& resumeObject = root->insert_preserve_copy("libtorrent_resume", torrent::Object::create_map()).first->second;
 
+  rtorrent->insert_key("key", download->tracker_controller().key());
+
   initialize_rtorrent(download, rtorrent);
 
   if (!rtorrent->has_key_string("custom1")) rtorrent->insert_key("custom1", std::string());
@@ -352,15 +356,17 @@ DownloadFactory::receive_failed(const std::string& msg) {
 
 void
 DownloadFactory::initialize_rtorrent(Download* download, torrent::Object* rtorrent) {
+  auto cached_seconds = torrent::this_thread::cached_seconds().count();
+
   if (!rtorrent->has_key_value("state") || rtorrent->get_key_value("state") > 1) {
     rtorrent->insert_key("state", (int64_t)m_start);
-    rtorrent->insert_key("state_changed", cachedTime.seconds());
+    rtorrent->insert_key("state_changed", cached_seconds);
     rtorrent->insert_key("state_counter", int64_t());
 
   } else if (!rtorrent->has_key_value("state_changed") ||
-             rtorrent->get_key_value("state_changed") > cachedTime.seconds() || rtorrent->get_key_value("state_changed") == 0 ||
+             rtorrent->get_key_value("state_changed") > cached_seconds || rtorrent->get_key_value("state_changed") == 0 ||
              !rtorrent->has_key_value("state_counter") || (uint64_t)rtorrent->get_key_value("state_counter") > (1 << 20)) {
-    rtorrent->insert_key("state_changed", cachedTime.seconds());
+    rtorrent->insert_key("state_changed", cached_seconds);
     rtorrent->insert_key("state_counter", int64_t());
   }
 
@@ -378,14 +384,6 @@ DownloadFactory::initialize_rtorrent(Download* download, torrent::Object* rtorre
   else
     rpc::call_command("d.priority.set", (int64_t)2, rpc::make_target(download));
 
-  if (rtorrent->has_key_value("key")) {
-    download->tracker_list()->set_key(rtorrent->get_key_value("key"));
-
-  } else {
-    download->tracker_list()->set_key(random() % (std::numeric_limits<uint32_t>::max() - 1) + 1);
-    rtorrent->insert_key("key", download->tracker_list()->key());
-  }
-
   if (rtorrent->has_key_value("total_uploaded"))
     download->info()->mutable_up_rate()->set_total(rtorrent->get_key_value("total_uploaded"));
 
