@@ -1,45 +1,8 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <algorithm>
 #include <fstream>
 #include <iostream>
-#include <rak/functional.h>
 #include <rak/string_manip.h>
 #include <torrent/data/file.h>
 #include <torrent/utils/resume.h>
@@ -71,7 +34,7 @@
 namespace core {
 
 inline void
-DownloadList::check_contains(Download* d) {
+DownloadList::check_contains([[maybe_unused]] Download* d) {
 #ifdef USE_EXTRA_DEBUG
   if (std::find(begin(), end(), d) == end())
     throw torrent::internal_error("DownloadList::check_contains(...) failed.");
@@ -80,15 +43,32 @@ DownloadList::check_contains(Download* d) {
 
 void
 DownloadList::clear() {
-  std::for_each(begin(), end(), std::bind1st(std::mem_fun(&DownloadList::close), this));
-  std::for_each(begin(), end(), rak::call_delete<Download>());
+  int error_count = 0;
 
-  base_type::clear();
+  while (!empty()) {
+    auto download = back();
+
+    try {
+      close(download);
+      base_type::pop_back();
+
+      torrent::download_remove(*download->download());
+      delete download;
+
+    } catch (torrent::internal_error& e) {
+      lt_log_print(torrent::LOG_ERROR, "DownloadList::clear() failed to close or remove download: %s", e.what());
+      error_count++;
+      continue;
+    }
+  }
+
+  if (error_count > 0)
+    throw torrent::internal_error("DownloadList::clear() failed to close or remove " + std::to_string(error_count) + " downloads.");
 }
 
 void
 DownloadList::session_save() {
-  unsigned int c = std::count_if(begin(), end(), std::bind1st(std::mem_fun(&DownloadStore::save_resume), control->core()->download_store()));
+  unsigned int c = std::count_if(begin(), end(), [&](Download* d) { return control->core()->download_store()->save_resume(d); });
 
   if (c != size())
     lt_log_print(torrent::LOG_ERROR, "Failed to save session torrents.");
@@ -99,7 +79,7 @@ DownloadList::session_save() {
 
 DownloadList::iterator
 DownloadList::find(const torrent::HashString& hash) {
-  return std::find_if(begin(), end(), rak::equal(hash, rak::on(std::mem_fun(&Download::info), std::mem_fun(&torrent::DownloadInfo::hash))));
+  return std::find_if(begin(), end(), [hash](Download* d) { return hash == d->info()->hash(); });
 }
 
 DownloadList::iterator
@@ -109,7 +89,7 @@ DownloadList::find_hex(const char* hash) {
   for (torrent::HashString::iterator itr = key.begin(), last = key.end(); itr != last; itr++, hash += 2)
     *itr = (rak::hexchar_to_value(*hash) << 4) + rak::hexchar_to_value(*(hash + 1));
 
-  return std::find_if(begin(), end(), rak::equal(key, rak::on(std::mem_fun(&Download::info), std::mem_fun(&torrent::DownloadInfo::hash))));
+  return std::find_if(begin(), end(), [key](Download* d) { return key == d->info()->hash(); });
 }
 
 Download*
@@ -120,18 +100,18 @@ DownloadList::find_hex_ptr(const char* hash) {
 }
 
 Download*
-DownloadList::create(torrent::Object* obj, bool printLog) {
+DownloadList::create(torrent::Object* obj, uint32_t tracker_key, bool printLog) {
   torrent::Download download;
 
   try {
-    download = torrent::download_add(obj);
+    download = torrent::download_add(obj, tracker_key);
 
   } catch (torrent::local_error& e) {
-    delete obj;
-
     if (printLog)
       lt_log_print(torrent::LOG_TORRENT_ERROR, "Could not create download: %s", e.what());
 
+    delete obj;
+
     return NULL;
   }
 
@@ -141,13 +121,13 @@ DownloadList::create(torrent::Object* obj, bool printLog) {
 }
 
 Download*
-DownloadList::create(std::istream* str, bool printLog) {
+DownloadList::create(std::istream* str, uint32_t tracker_key, bool printLog) {
   torrent::Object* object = new torrent::Object;
   torrent::Download download;
 
   try {
     *str >> *object;
-    
+
     // Don't throw input_error from here as gcc-3.3.5 produces bad
     // code.
     if (str->fail()) {
@@ -159,7 +139,7 @@ DownloadList::create(std::istream* str, bool printLog) {
       return NULL;
     }
 
-    download = torrent::download_add(object);
+    download = torrent::download_add(object, tracker_key);
 
   } catch (torrent::local_error& e) {
     delete object;
@@ -187,8 +167,8 @@ DownloadList::insert(Download* download) {
 
     // This needs to be separated into two different calls to ensure
     // the download remains in the view.
-    std::for_each(control->view_manager()->begin(), control->view_manager()->end(), std::bind2nd(std::mem_fun(&View::insert), download));
-    std::for_each(control->view_manager()->begin(), control->view_manager()->end(), std::bind2nd(std::mem_fun(&View::filter_download), download));
+    std::for_each(control->view_manager()->begin(), control->view_manager()->end(), [&download](View* v) { v->insert(download); });
+    std::for_each(control->view_manager()->begin(), control->view_manager()->end(), [&download](View* v) { v->filter_download(download); });
 
     DL_TRIGGER_EVENT(*itr, "event.download.inserted");
 
@@ -221,7 +201,7 @@ DownloadList::erase(iterator itr) {
   control->core()->download_store()->remove(*itr);
 
   DL_TRIGGER_EVENT(*itr, "event.download.erased");
-  std::for_each(control->view_manager()->begin(), control->view_manager()->end(), std::bind2nd(std::mem_fun(&View::erase), *itr));
+  std::for_each(control->view_manager()->begin(), control->view_manager()->end(), [itr](View* v) { v->erase(*itr); });
 
   torrent::download_remove(*(*itr)->download());
   delete *itr;
@@ -251,7 +231,7 @@ DownloadList::open_throw(Download* download) {
 
   if (download->download()->info()->is_open())
     return;
-  
+
   int openFlags = download->resume_flags();
 
   if (rpc::call_command_value("system.file.allocate"))
@@ -290,7 +270,7 @@ void
 DownloadList::close_quick(Download* download) {
   lt_log_print_info(torrent::LOG_TORRENT_INFO, download->info(), "download_list", "Closing download quickly.");
   close(download);
-  
+
   // Make sure we cancel any tracker requests. This should rather be
   // handled by some parameter to the close function, or some other
   // way of giving the client more control of when STOPPED requests
@@ -370,7 +350,9 @@ DownloadList::resume(Download* download, int flags) {
     // This will never actually do anything due to the above hash check.
     // open_throw(download);
 
-    rpc::call_command("d.state_changed.set", cachedTime.seconds(), rpc::make_target(download));
+    auto cached_seconds = torrent::this_thread::cached_seconds().count();
+
+    rpc::call_command("d.state_changed.set", cached_seconds, rpc::make_target(download));
     rpc::call_command("d.state_counter.set", rpc::call_command_value("d.state_counter", rpc::make_target(download)) + 1, rpc::make_target(download));
 
     if (download->is_done()) {
@@ -452,13 +434,15 @@ DownloadList::pause(Download* download, int flags) {
 
     download->download()->stop(flags);
     torrent::resume_save_progress(*download->download(), download->download()->bencode()->get_key("libtorrent_resume"));
-    
+
     // TODO: This is actually for pause, not stop... And doesn't get
     // called when the download isn't active, but was in the 'started'
     // view.
     DL_TRIGGER_EVENT(download, "event.download.paused");
 
-    rpc::call_command("d.state_changed.set", cachedTime.seconds(), rpc::make_target(download));
+    auto cached_seconds = torrent::this_thread::cached_seconds().count();
+
+    rpc::call_command("d.state_changed.set", cached_seconds, rpc::make_target(download));
     rpc::call_command("d.state_counter.set", rpc::call_command_value("d.state_counter", rpc::make_target(download)), rpc::make_target(download));
 
     // If initial seeding is complete, don't try it again when restarting.
@@ -550,8 +534,8 @@ DownloadList::hash_done(Download* download) {
     if (download->is_done()) {
       confirm_finished(download);
     } else {
-      download->set_message("Hash check on download completion found bad chunks, consider using \"safe_sync\".");
-      lt_log_print(torrent::LOG_TORRENT_ERROR, "Hash check on download completion found bad chunks, consider using \"safe_sync\".");
+      download->set_message("Hash check on download completion found bad chunks.");
+      lt_log_print(torrent::LOG_TORRENT_ERROR, "Hash check on download completion found bad chunks.");
       DL_TRIGGER_EVENT(download, "event.download.hash_final_failed");
     }
 
