@@ -1,44 +1,7 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <algorithm>
 #include <functional>
-#include <rak/functional.h>
 #include <torrent/download.h>
 #include <torrent/exceptions.h>
 
@@ -53,7 +16,7 @@
 namespace core {
 
 // Also add focus thingie here?
-struct view_downloads_compare : std::binary_function<Download*, Download*, bool> {
+struct view_downloads_compare : std::function<bool (Download*, Download*)> {
   view_downloads_compare(const torrent::Object& cmd) :
       m_command(cmd) {}
 
@@ -87,7 +50,7 @@ struct view_downloads_compare : std::binary_function<Download*, Download*, bool>
   const torrent::Object& m_command;
 };
 
-struct view_downloads_filter : std::unary_function<Download*, bool> {
+struct view_downloads_filter : std::function<bool (Download*)> {
   view_downloads_filter(const torrent::Object& cmd, const torrent::Object& cmd2) :
       m_command(cmd), m_command2(cmd2) {}
 
@@ -150,7 +113,7 @@ struct view_downloads_filter : std::unary_function<Download*, bool> {
 
 void
 View::emit_changed() {
-  priority_queue_update(&taskScheduler, &m_delayChanged, cachedTime);
+  torrent::this_thread::scheduler()->update_wait_for(&m_delay_changed, 0ms);
 }
 
 void
@@ -164,7 +127,7 @@ View::~View() {
     return;
 
   clear_filter_on();
-  priority_queue_erase(&taskScheduler, &m_delayChanged);
+  torrent::this_thread::scheduler()->erase(&m_delay_changed);
 }
 
 void
@@ -180,13 +143,12 @@ View::initialize(const std::string& name) {
   m_name = name;
 
   // Urgh, wrong. No filtering being done.
-  std::for_each(dlist->begin(), dlist->end(), rak::bind1st(std::mem_fun(&View::push_back), this));
+  std::for_each(dlist->begin(), dlist->end(), [&](Download* d) { push_back(d); });
 
   m_size  = base_type::size();
   m_focus = 0;
 
-  set_last_changed(rak::timer());
-  m_delayChanged.slot() = std::bind(&View::emit_changed_now, this);
+  m_delay_changed.slot() = [this]() { emit_changed_now(); };
 }
 
 void
@@ -236,20 +198,45 @@ View::set_not_visible(Download* download) {
 }
 
 void
-View::next_focus() {
+View::next_focus(unsigned int i) {
   if (empty())
     return;
 
-  m_focus = (m_focus + 1) % (size() + 1);
+  // If at the boundary, roll over
+  if (m_focus == size() - 1) {
+    m_focus = size();
+    emit_changed();
+    return;
+  }
+
+  // Move forward, stop at the boundary
+  if (m_focus == size()) // Needs special handling to ensure it's not off by one
+    m_focus = i - 1;
+  else
+    m_focus += i;
+  if (m_focus > size() - 1)
+    m_focus = size() - 1;
+
   emit_changed();
 }
 
 void
-View::prev_focus() {
+View::prev_focus(unsigned int i) {
   if (empty())
     return;
 
-  m_focus = (m_focus - 1 + size() + 1) % (size() + 1);
+  // If at the boundary, roll over
+  if (m_focus == size()) {
+    m_focus = size() - 1;
+    emit_changed();
+    return;
+  }
+
+  // Move backward, stop at the boundary
+  m_focus -= i;
+  if (m_focus < 0 || m_focus > size())
+    m_focus = size();
+
   emit_changed();
 }
 
@@ -360,7 +347,7 @@ View::clear_filter_on() {
 
 inline void
 View::insert_visible(Download* d) {
-  iterator itr = std::find_if(begin_visible(), end_visible(), std::bind1st(view_downloads_compare(m_sortNew), d));
+  iterator itr = std::find_if(begin_visible(), end_visible(), [&d, this](Download* d2) { return view_downloads_compare(m_sortNew)(d, d2); });
 
   m_size++;
   m_focus += (m_focus >= position(itr));
