@@ -1,45 +1,10 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
+#include "display/text_element_value.h"
+
 #include <ctime>
 
 #include "globals.h"
-#include "text_element_value.h"
 
 namespace display {
 
@@ -47,7 +12,7 @@ namespace display {
 void
 TextElement::push_attribute(Canvas::attributes_list* attributes, Attributes value) {
   Attributes base = attributes->back();
-  
+
   if (value.colors() == Attributes::color_invalid)
     value.set_colors(base.colors());
 
@@ -69,12 +34,12 @@ TextElementValueBase::print(char* first, char* last, Canvas::attributes_list* at
 
   // Transform the value if needed.
   if (m_flags & flag_elapsed)
-    val = cachedTime.seconds() - val;
+    val = torrent::this_thread::cached_seconds().count() - val;
   else if (m_flags & flag_remaining)
-    val = val - cachedTime.seconds();
+    val = val - torrent::this_thread::cached_seconds().count();
 
   if (m_flags & flag_usec)
-    val = rak::timer(val).seconds();
+    val = torrent::utils::cast_seconds(std::chrono::microseconds(val)).count();
 
   // Print the value.
   if (first == last) {
@@ -108,7 +73,7 @@ TextElementValueBase::print(char* first, char* last, Canvas::attributes_list* at
   } else if (m_flags & flag_date) {
     time_t t = val;
     std::tm *u = std::gmtime(&t);
-  
+
     if (u == NULL)
       return first;
 
@@ -117,7 +82,7 @@ TextElementValueBase::print(char* first, char* last, Canvas::attributes_list* at
   } else if (m_flags & flag_time) {
     time_t t = val;
     std::tm *u = std::gmtime(&t);
-  
+
     if (u == NULL)
       return first;
 
