@@ -80,6 +80,9 @@ char*       print_client_version(char* first, char* last, const torrent::ClientI
 char*       print_entry_tags(char* first, char* last);
 char*       print_entry_file(char* first, char* last, const torrent::Entry& entry);
 
+char*       print_status_throttle_limit(char* first, char* last, bool up, const std::vector<std::string>& throttle_names);
+char*       print_status_throttle_rate(char* first, char* last, bool up, const std::vector<std::string>& throttle_names, const double& global_rate);
+
 char*       print_status_info(char* first, char* last);
 char*       print_status_extra(char* first, char* last);
 
