@@ -1,61 +1,25 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
+#include "rpc/command_scheduler.h"
+
 #include <algorithm>
 #include <cstdlib>
 #include <time.h>
-#include <rak/functional.h>
 #include <rak/string_manip.h>
 #include <torrent/exceptions.h>
 
-#include "command_scheduler.h"
-#include "command_scheduler_item.h"
-#include "parse_commands.h"
+#include "rpc/command_scheduler_item.h"
+#include "rpc/parse_commands.h"
 
 namespace rpc {
 
 CommandScheduler::~CommandScheduler() {
-  std::for_each(begin(), end(), rak::call_delete<CommandSchedulerItem>());
+  std::for_each(begin(), end(), [](CommandSchedulerItem* item) { delete item; });
 }
 
 CommandScheduler::iterator
 CommandScheduler::find(const std::string& key) {
-  return std::find_if(begin(), end(), rak::equal(key, std::mem_fun(&CommandSchedulerItem::key)));
+  return std::find_if(begin(), end(), [key](CommandSchedulerItem* item) { return key == item->key(); });
 }
 
 CommandScheduler::iterator
@@ -105,14 +69,14 @@ CommandScheduler::call_item(value_type item) {
   }
 
   // Still schedule if we caught a torrrent::input_error?
-  rak::timer next = item->next_time_scheduled();
+  auto next = item->next_time_scheduled();
 
-  if (next == rak::timer()) {
+  if (next == std::chrono::microseconds(0)) {
     // Remove from scheduler?
     return;
   }
 
-  if (next <= cachedTime)
+  if (next <= torrent::this_thread::cached_time())
     throw torrent::internal_error("CommandScheduler::call_item(...) tried to schedule a zero interval item.");
 
   item->enable(next);
@@ -134,7 +98,7 @@ CommandScheduler::parse(const std::string& key,
   item->command() = command;
   item->set_interval(interval);
 
-  item->enable((cachedTime + rak::timer::from_seconds(absolute)).round_seconds());
+  item->enable(torrent::utils::ceil_seconds(torrent::this_thread::cached_time() + std::chrono::seconds(absolute)));
 }
 
 uint32_t
@@ -150,7 +114,7 @@ CommandScheduler::parse_absolute(const char* str) {
     return result.second;
 
   case 2:
-    t = cachedTime.tval().tv_sec;
+    t = torrent::this_thread::cached_seconds().count();
 
     if (localtime_r(&t, &local) == NULL)
       throw torrent::input_error("Could not convert unix time to local time.");
@@ -158,7 +122,7 @@ CommandScheduler::parse_absolute(const char* str) {
     return (result.second + 3600 - 60 * local.tm_min - local.tm_sec) % 3600;
 
   case 3:
-    t = cachedTime.tval().tv_sec;
+    t = torrent::this_thread::cached_seconds().count();
 
     if (localtime_r(&t, &local) == NULL)
       throw torrent::input_error("Could not convert unix time to local time.");
@@ -177,7 +141,7 @@ CommandScheduler::parse_interval(const char* str) {
 
   if (result.first == 0)
     throw torrent::input_error("Could not parse interval.");
-  
+
   return result.second;
 }
 
