@@ -29,10 +29,8 @@
 // If you delete this exception statement from all source files in the
 // program, then also delete it here.
 //
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
+// Contact:  Jari Sundell <sundell.software@gmail.com>
+
 
 #ifndef RTORRENT_RPC_IP_TABLE_LISTS_H
 #define RTORRENT_RPC_IP_TABLE_LISTS_H
@@ -45,7 +43,7 @@
 
 namespace rpc {
 
-typedef torrent::extents<uint32_t, int, 32, 256, 8> ipv4_table;
+typedef torrent::extents<uint32_t, int> ipv4_table;
 
 struct ip_table_node {
   std::string name;
