@@ -1,68 +1,25 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <algorithm>
 #include <fstream>
 #include <string>
-#include <rak/functional.h>
+#include <functional>
 #include <rak/path.h>
 #include <torrent/exceptions.h>
 
-#include "parse.h"
-#include "parse_commands.h"
+#include "rpc/parse.h"
+#include "rpc/parse_commands.h"
+#include "rpc/rpc_manager.h"
 
 namespace rpc {
 
-CommandMap commands;
-XmlRpc     xmlrpc;
-ExecFile   execFile;
+inline bool command_map_is_space(char c) {
+  return c == ' ' || c == '\t';
+}
 
-struct command_map_is_space : std::unary_function<char, bool> {
-  bool operator () (char c) const {
-    return c == ' ' || c == '\t';
-  }
-};
-
-struct command_map_is_newline : std::unary_function<char, bool> {
-  bool operator () (char c) const {
-    return c == '\n' || c == '\0' || c == ';';
-  }
-};
+inline bool command_map_is_newline(char c) {
+  return c == '\n' || c == '\0' || c == ';';
+}
 
 // Only escape eol on odd number of escape characters. We know that
 // there can't be any characters in between, so this should work for
@@ -131,16 +88,16 @@ parse_command_name(const char* first, const char* last, char* dest_first, char*
 // the code below for both cases.
 parse_command_type
 parse_command(target_type target, const char* first, const char* last) {
-  first = std::find_if(first, last, std::not1(command_map_is_space()));
+  first = std::find_if(first, last, [&](char c) { return !command_map_is_space(c); });
 
   if (first == last || *first == '#')
     return std::make_pair(torrent::Object(), first);
-  
+
   char key[128];
 
   first = parse_command_name(first, last, key, key + 128);
-  first = std::find_if(first, last, std::not1(command_map_is_space()));
-  
+  first = std::find_if(first, last, [&](char c) { return !command_map_is_space(c); });
+
   if (first == last || *first != '=')
     throw torrent::input_error("Could not find '=' in command '" + std::string(key) + "'.");
 
@@ -150,10 +107,10 @@ parse_command(target_type target, const char* first, const char* last) {
   // Find the last character that is part of this command, skipping
   // the whitespace at the end. This ensures us that the caller
   // doesn't need to do this nor check for junk at the end.
-  first = std::find_if(first, last, std::not1(command_map_is_space()));
-  
+  first = std::find_if(first, last, [&](char c) { return !command_map_is_space(c); });
+
   if (first != last) {
-    if (*first != '\n' && *first != ';' && *first != '\0')
+    if (!command_map_is_newline(*first))
       throw torrent::input_error("Junk at end of input.");
 
     first++;
@@ -196,7 +153,7 @@ parse_command_file(const std::string& path) {
 
     while (file.good()
            && !file.getline(buffer + getCount, 4096 - getCount).fail()) {
-      
+
       if (file.gcount() == 0)
         throw torrent::internal_error("parse_command_file(...) file.gcount() == 0.");
       int lineLength = file.gcount() - 1;
@@ -205,7 +162,7 @@ parse_command_file(const std::string& path) {
       // that the last would also be included in option line.
       if (file.eof() && file.get() != '\n')
         lineLength++;
-      
+
       int escaped = parse_count_escaped(buffer + getCount, buffer + getCount + lineLength);
 
       lineNumber++;
@@ -213,7 +170,7 @@ parse_command_file(const std::string& path) {
 
       if (getCount == 4096 - 1)
         throw torrent::input_error("Exceeded max line length.");
-      
+
       if (escaped & 0x1) {
         // Remove the escape characters and continue reading.
         getCount -= escaped;
