@@ -1,41 +1,6 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
+#include <cassert>
 #include <rak/error_number.h>
 #include <rak/socket_address.h>
 #include <sys/un.h>
@@ -44,12 +9,13 @@
 #include <torrent/torrent.h>
 #include <torrent/exceptions.h>
 
-#include "utils/socket_fd.h"
-
 #include "control.h"
 #include "globals.h"
-#include "scgi.h"
-#include "parse_commands.h"
+#include "rpc/scgi_task.h"
+#include "utils/socket_fd.h"
+
+// TODO: Figure out why moving this to the top causes a build error.
+#include "rpc/scgi.h"
 
 namespace rpc {
 
@@ -122,18 +88,22 @@ SCgi::open(void* sa, unsigned int length) {
   }
 }
 
+// TODO: Verify this is run in correct thread, also only ever call poll methods from thread_self.
+
 void
 SCgi::activate() {
-  worker_thread->poll()->open(this);
-  worker_thread->poll()->insert_read(this);
-  worker_thread->poll()->insert_error(this);
+  assert(std::this_thread::get_id() == worker_thread->thread_id() && "SCgi::activate() must be called from the worker thread.");
+
+  torrent::this_thread::poll()->open(this);
+  torrent::this_thread::poll()->insert_read(this);
+  torrent::this_thread::poll()->insert_error(this);
 }
 
 void
 SCgi::deactivate() {
-  worker_thread->poll()->remove_read(this);
-  worker_thread->poll()->remove_error(this);
-  worker_thread->poll()->close(this);
+  assert(std::this_thread::get_id() == worker_thread->thread_id() && "SCgi::deactivate() must be called from the worker thread.");
+
+  torrent::this_thread::poll()->remove_and_close(this);
 }
 
 void
@@ -142,14 +112,13 @@ SCgi::event_read() {
   utils::SocketFd fd;
 
   while ((fd = get_fd().accept(&sa)).is_valid()) {
-    SCgiTask* task = std::find_if(m_task, m_task + max_tasks, std::mem_fun_ref(&SCgiTask::is_available));
+    SCgiTask* task = std::find_if(m_task, m_task + max_tasks, std::mem_fn(&SCgiTask::is_available));
 
     if (task == m_task + max_tasks) {
-      // Ergh... just closing for now.
       fd.close();
       continue;
     }
-    
+
     task->open(this, fd.get_fd());
   }
 }
@@ -164,16 +133,4 @@ SCgi::event_error() {
   throw torrent::internal_error("SCGI listener port received an error event.");
 }
 
-bool
-SCgi::receive_call(SCgiTask* task, const char* buffer, uint32_t length) {
-  torrent::thread_base::acquire_global_lock();
-  torrent::main_thread()->interrupt();
-
-  bool result = xmlrpc.process(buffer, length, [task](const char* b, uint32_t l) { return task->receive_write(b, l); });
-
-  torrent::thread_base::release_global_lock();
-
-  return result;
-}
-
 }
