@@ -1,44 +1,8 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
+#include <cassert>
 #include <sstream>
 
-#include <rak/functional.h>
 #include <rak/string_manip.h>
 #include <torrent/exceptions.h>
 #include <torrent/torrent.h>
@@ -69,9 +33,7 @@
 
 namespace ui {
 
-DownloadList::DownloadList() :
-  m_state(DISPLAY_MAX_SIZE) {
-
+DownloadList::DownloadList() {
   m_uiArray[DISPLAY_DOWNLOAD]      = NULL;
   m_uiArray[DISPLAY_DOWNLOAD_LIST] = new ElementDownloadList();
   m_uiArray[DISPLAY_LOG]           = new ElementLogComplete(control->core()->log_complete());
@@ -83,16 +45,15 @@ DownloadList::DownloadList() :
 }
 
 DownloadList::~DownloadList() {
-  if (is_active())
-    throw std::logic_error("ui::DownloadList::~DownloadList() called on an active object");
+  assert(!is_active() && "ui::DownloadList::~DownloadList() called on an active object");
 
-  std::for_each(m_uiArray, m_uiArray + DISPLAY_MAX_SIZE, rak::call_delete<ElementBase>());
+  std::for_each(m_uiArray, m_uiArray + DISPLAY_MAX_SIZE, [](ElementBase* eb) { delete eb; });
 
   delete m_windowLog;
 }
 
 void
-DownloadList::activate(display::Frame* frame, bool focus) {
+DownloadList::activate(display::Frame* frame, [[maybe_unused]] bool focus) {
   if (is_active())
     throw torrent::internal_error("ui::DownloadList::activate() called on an already activated object");
 
