@@ -1,43 +1,9 @@
-// rTorrent - BitTorrent client
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef RTORRENT_UI_ROOT_H
 #define RTORRENT_UI_ROOT_H
 
 #include <cstdint>
+#include <memory>
+
 #include "input/bindings.h"
 #include "download_list.h"
 
@@ -77,11 +43,11 @@ public:
   void                init(Control* c);
   void                cleanup();
 
-  WTitle*             window_title()                          { return m_windowTitle; }
-  WStatusbar*         window_statusbar()                      { return m_windowStatusbar; }
-  WInput*             window_input()                          { return m_windowInput; }
+  WTitle*             window_title()                          { return m_windowTitle.get(); }
+  WStatusbar*         window_statusbar()                      { return m_windowStatusbar.get(); }
+  WInput*             window_input()                          { return m_windowInput.get(); }
 
-  DownloadList*       download_list()                         { return m_downloadList; }
+  DownloadList*       download_list()                         { return m_downloadList.get(); }
 
   void                set_down_throttle(unsigned int throttle);
   void                set_up_throttle(unsigned int throttle);
@@ -117,21 +83,21 @@ public:
 private:
   void                setup_keys();
 
-  Control*            m_control;
-  DownloadList*       m_downloadList;
+  Control*                      m_control{nullptr};
+  std::unique_ptr<DownloadList> m_downloadList;
 
-  WTitle*             m_windowTitle;
-  WHttpQueue*         m_windowHttpQueue;
-  WInput*             m_windowInput;
-  WStatusbar*         m_windowStatusbar;
+  std::unique_ptr<WTitle>       m_windowTitle;
+  std::unique_ptr<WHttpQueue>   m_windowHttpQueue;
+  std::unique_ptr<WInput>       m_windowInput;
+  std::unique_ptr<WStatusbar>   m_windowStatusbar;
 
-  input::Bindings     m_bindings;
+  input::Bindings      m_bindings;
 
-  int                   m_input_history_length;
-  std::string           m_input_history_last_input;
-  int                   m_input_history_pointer_get;
-  InputHistory          m_input_history;
-  InputHistoryPointers  m_input_history_pointers;
+  int                  m_input_history_length{99};
+  std::string          m_input_history_last_input{""};
+  int                  m_input_history_pointer_get{0};
+  InputHistory         m_input_history;
+  InputHistoryPointers m_input_history_pointers;
 
   void                prev_in_input_history(ui::DownloadList::Input type);
   void                next_in_input_history(ui::DownloadList::Input type);
