@@ -29,15 +29,13 @@
 // If you delete this exception statement from all source files in the
 // program, then also delete it here.
 //
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
+// Contact:  Jari Sundell <sundell.software@gmail.com>
+
 
 #ifndef RTORRENT_UTILS_LIST_FOCUS_H
 #define RTORRENT_UTILS_LIST_FOCUS_H
 
-#include lt_tr1_functional
+#include <functional>
 
 namespace utils {
 
